@@ -4,7 +4,7 @@
 # if you have many models here with many references from one model to another this may
 # raise a RecursionError
 # to avoid this, import only the models that you directly need like:
-# from basistheory.model.pet import Pet
+# from from basistheory.model.pet import Pet
 # or import this package, but before doing it, use:
 # import sys
 # sys.setrecursionlimit(n)
@@ -13,11 +13,13 @@ from basistheory.model.access_rule import AccessRule
 from basistheory.model.application import Application
 from basistheory.model.application_paginated_list import ApplicationPaginatedList
 from basistheory.model.application_template import ApplicationTemplate
+from basistheory.model.authorize_session_request import AuthorizeSessionRequest
 from basistheory.model.condition import Condition
 from basistheory.model.create_application_request import CreateApplicationRequest
 from basistheory.model.create_proxy_request import CreateProxyRequest
 from basistheory.model.create_reactor_formula_request import CreateReactorFormulaRequest
 from basistheory.model.create_reactor_request import CreateReactorRequest
+from basistheory.model.create_session_response import CreateSessionResponse
 from basistheory.model.create_tenant_invitation_request import CreateTenantInvitationRequest
 from basistheory.model.create_token_request import CreateTokenRequest
 from basistheory.model.create_token_response import CreateTokenResponse
@@ -42,6 +44,7 @@ from basistheory.model.privacy import Privacy
 from basistheory.model.problem_details import ProblemDetails
 from basistheory.model.proxy import Proxy
 from basistheory.model.proxy_paginated_list import ProxyPaginatedList
+from basistheory.model.proxy_transform import ProxyTransform
 from basistheory.model.react_request import ReactRequest
 from basistheory.model.react_response import ReactResponse
 from basistheory.model.reactor import Reactor
